==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl<ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder> implements VisitableBuilder<ConnectionPoolSettingsTCPSettingsTcpKeepalive,ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder>{
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder() {
    this(false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(Boolean validationEnabled) {
    this(new ConnectionPoolSettingsTCPSettingsTcpKeepalive(), validationEnabled);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent) {
    this(fluent, false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConnectionPoolSettingsTCPSettingsTcpKeepalive(), validationEnabled);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent,ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    this(fluent, instance, false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent,ConnectionPoolSettingsTCPSettingsTcpKeepalive instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withInterval(instance.getInterval());
      fluent.withProbes(instance.getProbes());
      fluent.withTime(instance.getTime());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    this(instance,false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withInterval(instance.getInterval());
      this.withProbes(instance.getProbes());
      this.withTime(instance.getTime());
    }
    this.validationEnabled = validationEnabled; 
  }
  ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent;
  Boolean validationEnabled;
  public ConnectionPoolSettingsTCPSettingsTcpKeepalive build() {
    ConnectionPoolSettingsTCPSettingsTcpKeepalive buildable = new ConnectionPoolSettingsTCPSettingsTcpKeepalive(fluent.getInterval(),fluent.getProbes(),fluent.getTime());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder> implements VisitableBuilder<ConnectionPoolSettingsTCPSettingsTcpKeepalive,ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder>{
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder() {
    this(false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(Boolean validationEnabled) {
    this(new ConnectionPoolSettingsTCPSettingsTcpKeepalive(), validationEnabled);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent) {
    this(fluent, false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConnectionPoolSettingsTCPSettingsTcpKeepalive(), validationEnabled);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent,ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    this(fluent, instance, false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent,ConnectionPoolSettingsTCPSettingsTcpKeepalive instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ConnectionPoolSettingsTCPSettingsTcpKeepalive());

    if (instance != null) {
      fluent.withInterval(instance.getInterval());
      fluent.withProbes(instance.getProbes());
      fluent.withTime(instance.getTime());
      fluent.withInterval(instance.getInterval());
      fluent.withProbes(instance.getProbes());
      fluent.withTime(instance.getTime());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    this(instance,false);
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ConnectionPoolSettingsTCPSettingsTcpKeepalive());

    if (instance != null) {
      this.withInterval(instance.getInterval());
      this.withProbes(instance.getProbes());
      this.withTime(instance.getTime());
      this.withInterval(instance.getInterval());
      this.withProbes(instance.getProbes());
      this.withTime(instance.getTime());
    }
    this.validationEnabled = validationEnabled; 
  }
  ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<?> fluent;
  Boolean validationEnabled;
  public ConnectionPoolSettingsTCPSettingsTcpKeepalive build() {
    ConnectionPoolSettingsTCPSettingsTcpKeepalive buildable = new ConnectionPoolSettingsTCPSettingsTcpKeepalive(fluent.getInterval(),fluent.getProbes(),fluent.getTime());
    return buildable;
  }
  
}
